NgftTextStyle class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

bold2xl → const TextStyle
bold2xs → const TextStyle
bold3xl → const TextStyle
bold3xs → const TextStyle
bold4xl → const TextStyle
bold4xs → const TextStyle
bold5xl → const TextStyle
bold6xl → const TextStyle
bold7xl → const TextStyle
bold8xl → const TextStyle
bold9xl → const TextStyle
boldBase → const TextStyle
boldLg → const TextStyle
boldSm → const TextStyle
boldXl → const TextStyle
boldXs → const TextStyle
fontFamily → const String
medium2xl → const TextStyle
medium2xs → const TextStyle
medium3xl → const TextStyle
medium3xs → const TextStyle
medium4xl → const TextStyle
medium4xs → const TextStyle
medium5xl → const TextStyle
medium6xl → const TextStyle
medium7xl → const TextStyle
medium8xl → const TextStyle
medium9xl → const TextStyle
mediumBase → const TextStyle
mediumLg → const TextStyle
mediumSm → const TextStyle
mediumXl → const TextStyle
mediumXs → const TextStyle
regular2xl → const TextStyle
regular2xs → const TextStyle
regular3xl → const TextStyle
regular3xs → const TextStyle
regular4xl → const TextStyle
regular4xs → const TextStyle
regular5xl → const TextStyle
regular6xl → const TextStyle
regular7xl → const TextStyle
regular8xl → const TextStyle
regular9xl → const TextStyle
regularBase → const TextStyle
regularLg → const TextStyle
regularSm → const TextStyle
regularXl → const TextStyle
regularXs → const TextStyle